## References

### rHEALPix
https://github.com/manaakiwhenua/rhealpixdggs-py

### DGGRID
https://github.com/sahrk/DGGRID
https://github.com/allixender/dggrid4py

### OpenEAGGR DGGS
https://github.com/riskaware-ltd/open-eaggr?tab=readme-ov-file
https://github.com/riskaware-ltd/open-eaggr/blob/master/EAGGRPython/eaggr/eaggr.py